package cesg.io;

import java.io.File;
import java.util.Collection;
import java.util.List;

/**
 * Interfaz para la escritura/lectura de archivo de textos.
 * @author kristian
 * @version 0.0.1
 */
public interface FileText {

    /**
     * Establece el archivo a manejar el texto.
     * @param file archivo ha editar.
     */
    public void setArchivo(File file);
    /**
     * 
     * @return verdadero si se puede leer.
     */
    public boolean puedeLeer();
    /**
     * @return verdadero si se puede escribir.
     */
    public boolean puedeEscribir();
    /**
     * @return verdadero si existe.
     */
    public boolean existe();
    /**
     * @return verdadero si se puede crear.
     */
    public boolean crear();
    /**
     * @return la direccion del archivo.
     */
    public String getDirFile();

    /**
     * Escribe un String en un archivo de texto.
     * @param contenido
     * @param continua continua True si se desea continuar escribiendo <br />
     *        False si quiere sobrescribir.
     */
    public void write(String contenido, boolean continua);
    
    /**
     * Escribe un Collection en un archivo de texto.
     * @param coleccion colecion a escribir(List,Map..).
     * @param continua True si se desea continuar escribiendo <br />
     *        False si quiere sobrescribir.
     */
    public void write(Collection<String> coleccion, boolean continua);
    
    /**
     * lee el contenido de un archivo de texto.
     * @return Lista de String con el contenido.
     */
    public List<String> readList();
    
    /**
     * lee el contenido de un archivo de texto.
     * @return String con el contenido.
     */
    public String read();
    
}
