package cesg.io;

import java.io.BufferedWriter;
import java.io.File;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.IOException;
import java.io.PrintWriter;
import java.util.ArrayList;
import java.util.Collection;
import java.util.List;
import java.util.Scanner;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;


/**
 * Impementacion de escritura/lectura de archivo de textos.
 * @author kristian
 * @version 0.0.1
 */
public class FileTextImp implements FileText {
    
    private File file;
    private static final Logger logger = LoggerFactory.getLogger(FileTextImp.class);
    public void setArchivo(File file) {
        this.file = file;
    }

    public boolean puedeLeer() {
        return file.canRead();
    }

    public boolean puedeEscribir() {
        return file.canWrite();
    }

    public boolean existe() {
        return file.exists();
    }

    public boolean crear() {
        try {
            if (!existe())
                return file.createNewFile();
        } catch (IOException e) {
            logger.error("Erro no se puede crear el archivo.\n", e);
        }
        return Boolean.FALSE;
    }

    public String getDirFile() {
        return file.getAbsolutePath();
    }

    public void write(String contenido, boolean continua) {
        try {
            final FileWriter fileWrite = new FileWriter(file, continua);
            final BufferedWriter fBuffer = new BufferedWriter(fileWrite);
            PrintWriter pWriter = new PrintWriter(fBuffer);
            pWriter.println(contenido);
            fBuffer.close();
        } catch (IOException e) {
            logger.error("Erro no se puede escribir en el archivo.\n", e);
        }

    }

    public void write(Collection<String> coleccion, boolean continua) {
        try {
            final FileWriter fileWrite = new FileWriter(file, continua);
            BufferedWriter fBuffer = new BufferedWriter(fileWrite);
            PrintWriter pw = new PrintWriter(fBuffer);
            if (coleccion != null) {
                for (String itr : coleccion) {
                    pw.println(itr);
                }
            }
            fBuffer.close();
        } catch (IOException e) {
            logger.error("Erro no se puede escribir en el archivo.\n", e);
        }

    }

    public List<String> readList() {
        List<String> listaContenido = new ArrayList<String>();

        if (puedeLeer()) {
            try {
                FileReader fileReader = new FileReader(file);
                final Scanner lector = new Scanner(fileReader);
                while (lector.hasNext()) {
                    listaContenido.add(lector.nextLine());
                }
                lector.close();
            } catch (Exception e) {
                logger.error("Erro no se puede leer el archivo.\n", e);
            }
        }
        return listaContenido;
    }

    public String read() {
        StringBuffer str = new StringBuffer();
        if (puedeLeer()) {
            try {
                FileReader fileReader = new FileReader(file);
                final Scanner lector = new Scanner(fileReader);
                while (lector.hasNext()) {
                    str.append(lector.nextLine());
                }
                lector.close();
            } catch (IOException e) {
                logger.error("Erro no se puede leer el archivo.\n", e);
            }
        }
        return str.toString();
    }

}
